@@ -7,10 +7,15 @@
 # Imports
 # --------------------------------------------------------------------------------------
 from ._shared import MOBase
+from ._shared import MORef
+from ._shared import OpenValidity
+from ._shared import Validity
+from .class_ import ClassRead
 from .employee import Employee
 from .employee import EmployeeRead
 from .employee import EmployeeWrite
 from .facet import FacetClass
+from .facet import FacetRead
 from .organisation import OrganisationRead
 from .organisation_unit import OrganisationUnit
 from .organisation_unit import OrganisationUnitRead
@@ -21,13 +26,18 @@ from .organisation_unit import OrganisationUnitWrite
 # --------------------------------------------------------------------------------------
 
 __all__ = [
-    "MOBase",
+    "ClassRead",
     "Employee",
     "EmployeeRead",
     "EmployeeWrite",
     "FacetClass",
+    "FacetRead",
+    "MOBase",
+    "MORef",
+    "OpenValidity",
     "OrganisationRead",
     "OrganisationUnit",
     "OrganisationUnitRead",
     "OrganisationUnitWrite",
+    "Validity",
 ]
