@@ -25,6 +25,7 @@ from .._shared import OrgUnitRef
 from .._shared import PersonRef
 from .._shared import Primary
 from .._shared import Validity
+from ._shared import Details
 
 # --------------------------------------------------------------------------------------
 # Engagement models
@@ -109,6 +110,10 @@ class AssociationWrite(AssociationBase):
         return v
 
 
+class AssociationDetail(AssociationWrite, Details):
+    pass
+
+
 class Association(MOBase):
     """
     A MO association object.
