@@ -13,8 +13,6 @@ from uuid import UUID
 from pydantic import Field
 
 from .._shared import EmployeeRef
-from .._shared import EngagementAssociationType
-from .._shared import EngagementRef
 from .._shared import EngagementType
 from .._shared import JobFunction
 from .._shared import LeaveRef
@@ -23,6 +21,7 @@ from .._shared import OrgUnitRef
 from .._shared import PersonRef
 from .._shared import Primary
 from .._shared import Validity
+from ._shared import Details
 
 # --------------------------------------------------------------------------------------
 # Engagement models
@@ -73,9 +72,6 @@ class EngagementRead(EngagementBase):
     primary_uuid: Optional[UUID] = Field(
         description="UUID of the primary klasse of the engagement."
     )
-    is_primary: Optional[bool] = Field(
-        description="Indication of whether this engagement is the primary."
-    )
 
 
 class EngagementWrite(EngagementBase):
@@ -113,6 +109,10 @@ class EngagementWrite(EngagementBase):
     )
 
 
+class EngagementDetail(EngagementWrite, Details):
+    pass
+
+
 class Engagement(MOBase):
     """A MO engagement object."""
 
@@ -206,57 +206,3 @@ class Engagement(MOBase):
             extension_9=extension_9,
             extension_10=extension_10,
         )
-
-
-class EngagementAssociation(MOBase):
-    """A MO engagement association object."""
-
-    type_: Literal["engagement_association"] = Field(
-        "engagement_association", alias="type", description="The object type."
-    )
-    org_unit: OrgUnitRef = Field(
-        description=(
-            "Reference to the organisation unit "
-            "for which the engagement association should be created."
-        )
-    )
-    engagement: EngagementRef = Field(
-        description=(
-            "Reference to the engagement "
-            "for which the engagement association should be created."
-        )
-    )
-    engagement_association_type: EngagementAssociationType = Field(
-        description=(
-            "Reference to the engagement association type klasse "
-            "for the created engagement association object."
-        )
-    )
-    validity: Validity = Field(
-        description="Validity of the created engagement association."
-    )
-
-    @classmethod
-    def from_simplified_fields(
-        cls,
-        org_unit_uuid: UUID,
-        engagement_uuid: UUID,
-        engagement_association_type_uuid: UUID,
-        from_date: str,
-        to_date: Optional[str] = None,
-        uuid: Optional[UUID] = None,
-    ) -> "EngagementAssociation":
-        """Create an engagement association from simplified fields."""
-        validity = Validity(from_date=from_date, to_date=to_date)
-        org_unit = OrgUnitRef(uuid=org_unit_uuid)
-        engagement = EngagementRef(uuid=engagement_uuid)
-        engagement_association_type = EngagementAssociationType(
-            uuid=engagement_association_type_uuid
-        )
-        return cls(
-            uuid=uuid,
-            org_unit=org_unit,
-            engagement=engagement,
-            engagement_association_type=engagement_association_type,
-            validity=validity,
-        )
